@@ -29,6 +29,7 @@
 #include "track-list-loader.h"
 #include <gstreamermm/playbin2.h>
 #include <gstreamermm/fakesink.h>
+#include <iomanip>
 
 VCMAWindow* VCMAWindow::create()
 {
@@ -46,7 +47,9 @@ VCMAWindow* VCMAWindow::create()
 VCMAWindow::VCMAWindow(BaseObjectType* baseObject, 
                              const Glib::RefPtr<Gtk::Builder>& xml)
  : Gtk::Window(baseObject), duration_column("Duration", duration_renderer),
-    license_column("License", license_renderer)
+    license_column("License", license_renderer),
+    song_and_artist_column("Song/Artist", song_and_artist_renderer),
+    rating_column("Album\nRating", rating_renderer)
 {
 
   xml->get_widget("contents", contents);
@@ -66,14 +69,19 @@ VCMAWindow::VCMAWindow(BaseObjectType* baseObject,
   duration_column.set_cell_data_func
     (duration_renderer, sigc::mem_fun(*this, &VCMAWindow::cell_data_duration));
   treeview->append_column(duration_column);
-  treeview->append_column("Genre", songs_columns.genre);
-  treeview->append_column("Artist", songs_columns.artist_name);
-  treeview->append_column("Song", songs_columns.song_title);
-  treeview->signal_row_activated().connect
-    (sigc::mem_fun(*this, &VCMAWindow::on_song_activated));
   license_column.set_cell_data_func
     (license_renderer, sigc::mem_fun(*this, &VCMAWindow::cell_data_license));
   treeview->append_column(license_column);
+  treeview->append_column("Genre", songs_columns.genre);
+  song_and_artist_column.set_cell_data_func
+    (song_and_artist_renderer, sigc::mem_fun(*this, &VCMAWindow::cell_data_song_and_artist));
+  treeview->append_column(song_and_artist_column);
+  rating_column.set_cell_data_func
+    (rating_renderer, sigc::mem_fun(*this, &VCMAWindow::cell_data_rating));
+  treeview->append_column(rating_column);
+
+  treeview->signal_row_activated().connect
+    (sigc::mem_fun(*this, &VCMAWindow::on_song_activated));
 
   Gtk::Menu::MenuList& menulist = treeview_context_menu.items();
   menulist.push_back
@@ -86,20 +94,20 @@ VCMAWindow::VCMAWindow(BaseObjectType* baseObject,
   treeview_context_menu.accelerate(*this);
 
   treeview->get_column(0)->set_sort_column(songs_columns.duration);
-  treeview->get_column(1)->set_sort_column(songs_columns.genre);
-  treeview->get_column(1)->set_min_width(50);
-  treeview->get_column(1)->set_max_width(200);
-  treeview->get_column(1)->set_resizable(true);
-  treeview->get_column(1)->set_expand(false);
-  treeview->get_column(2)->set_sort_column(songs_columns.song_title);
-  treeview->get_column(2)->set_min_width(50);
-  treeview->get_column(2)->set_max_width(200);
-  treeview->get_column(2)->set_resizable(true);
-  treeview->get_column(3)->set_sort_column(songs_columns.artist_name);
-  treeview->get_column(3)->set_fixed_width(100);
+  treeview->get_column(1)->set_sort_column(songs_columns.license);
+  treeview->get_column(1)->set_fixed_width(100);
+  treeview->get_column(2)->set_sort_column(songs_columns.genre);
+  treeview->get_column(2)->set_fixed_width(100);
+  treeview->get_column(2)->set_max_width(100);
+  treeview->get_column(2)->set_expand(false);
+  treeview->set_tooltip_column(2);
+  treeview->get_column(3)->set_sort_column(songs_columns.song_title);
+  treeview->get_column(3)->set_min_width(50);
+  treeview->get_column(3)->set_max_width(200);
   treeview->get_column(3)->set_resizable(true);
-  treeview->get_column(4)->set_sort_column(songs_columns.license);
-  treeview->get_column(4)->set_fixed_width(100);
+  treeview->get_column(3)->set_expand(true);
+  treeview->get_column(4)->set_sort_column(songs_columns.album_rating);
+  treeview->get_column(4)->set_expand(false);
 
   //menubar callbacks
   xml->get_widget("search_button", search_button);
@@ -133,6 +141,7 @@ VCMAWindow::VCMAWindow(BaseObjectType* baseObject,
   video_file_box->drag_dest_set(targets);
   video_file_box->signal_drag_data_received().connect
     (sigc::mem_fun(*this, &VCMAWindow::on_drag_data_received));
+  xml->get_widget("statusbar", statusbar);
 }
 
 void VCMAWindow::on_window_loaded()
@@ -148,6 +157,7 @@ VCMAWindow::~VCMAWindow()
 
 void VCMAWindow::load_catalogue_in_the_background(TrackList *track_list, guint32 secs)
 {
+  statusbar->push("Downloading music catalogue from jamendo.com...");
   d_loader->load("http://img.jamendo.com/data/dbdump.en.xml.gz", track_list,
                  sigc::bind(sigc::mem_fun(this, 
                                           &VCMAWindow::on_catalogue_loaded), 
@@ -157,6 +167,7 @@ void VCMAWindow::load_catalogue_in_the_background(TrackList *track_list, guint32
 
 void VCMAWindow::on_load_catalogue_aborted()
 {
+  statusbar->push("Could not download music catalogue from jamendo.com.");
   contents->set_sensitive(true);
   search_label->set_text("Search");
   results_label->set_text("");
@@ -165,6 +176,7 @@ void VCMAWindow::on_load_catalogue_aborted()
 
 void VCMAWindow::on_catalogue_loaded(TrackList *track_list, guint32 secs)
 {
+  statusbar->push("Downloaded music catalogue from jamendo.com.");
   d_connected = true;
   d_track_list->add(track_list);
   Glib::signal_idle().connect_once(sigc::bind(sigc::mem_fun(*this, &VCMAWindow::search_tracks_in_the_background), d_track_list, secs));
@@ -255,6 +267,7 @@ void VCMAWindow::on_search_clicked()
       d_loader->reset();
       contents->set_sensitive(true);
       unshow_spinner();
+      statusbar->push("");
     }
   else
     {
@@ -273,6 +286,7 @@ void VCMAWindow::on_search_clicked()
 
 void VCMAWindow::search_tracks_in_the_background(TrackList *track_list, guint32 duration)
 {
+  statusbar->push("Searching for suitably licensed songs...");
   guint32 min = duration;
   if (min > 0)
     min--;
@@ -297,8 +311,9 @@ void VCMAWindow::search_tracks_in_the_background(TrackList *track_list, guint32
 
   if (songs->size() == 0)
     {
-    results_label->set_text("No songs were found.");
-  unshow_spinner();
+      results_label->set_text("No songs were found.");
+      unshow_spinner();
+      statusbar->push("");
     }
 
   return;
@@ -306,10 +321,10 @@ void VCMAWindow::search_tracks_in_the_background(TrackList *track_list, guint32
 
 void VCMAWindow::on_album_license_not_loaded(guint32 album_id, TrackList *songs)
 {
-  on_album_license_loaded(album_id, "Unknown", songs);
+  on_album_license_loaded(album_id, "Unknown", Glib::RefPtr<Gdk::Pixbuf>(0), 0.0, songs);
 }
 
-void VCMAWindow::on_album_license_loaded(guint32 album_id, Glib::ustring license, TrackList *songs)
+void VCMAWindow::on_album_license_loaded(guint32 album_id, Glib::ustring license, Glib::RefPtr<Gdk::Pixbuf> license_image, double rating, TrackList *songs)
 {
   std::string l = license;
   bool completely_filled = true;
@@ -320,9 +335,10 @@ void VCMAWindow::on_album_license_loaded(guint32 album_id, Glib::ustring license
       if ((*i)->get_album_id() == album_id)
         {
           (*i)->set_license(license);
+          (*i)->set_album_rating(rating);
           if (license.find("nd") == Glib::ustring::npos && license != "Unknown")
             {
-              add_song_row(**i);
+              add_song_row(**i, license_image);
 
               guint32 count = songs_list->children().size();
               if (count == 1)
@@ -340,10 +356,11 @@ void VCMAWindow::on_album_license_loaded(guint32 album_id, Glib::ustring license
     {
       unshow_spinner();
       search_label->set_text("Search");
+      statusbar->push("");
     }
 }
 
-void VCMAWindow::add_song_row(const Track &track)
+void VCMAWindow::add_song_row(const Track &track, Glib::RefPtr<Gdk::Pixbuf> license_image)
 {
   Gtk::TreeIter i = songs_list->append();
   (*i)[songs_columns.duration] = track.get_duration();
@@ -353,12 +370,16 @@ void VCMAWindow::add_song_row(const Track &track)
   (*i)[songs_columns.album_id] = track.get_album_id();
   (*i)[songs_columns.track_id] = track.get_track_id();
   (*i)[songs_columns.license] = track.get_license();
+  (*i)[songs_columns.license_image] = license_image;
+  (*i)[songs_columns.album_rating] = track.get_album_rating();
   treeview->show_all();
 }
 
 void VCMAWindow::cell_data_license(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i)
 {
-  Gtk::CellRendererText*cell = dynamic_cast<Gtk::CellRendererText*>(renderer);
+  Gtk::CellRendererPixbuf *cell = dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);
+  cell->property_pixbuf() = (*i)[songs_columns.license_image];
+  /*
   Glib::ustring l = (*i)[songs_columns.license];
   std::vector < Glib::ustring > a = Glib::Regex::split_simple ("/", l);
   if (a.size () <= 1)
@@ -372,8 +393,56 @@ void VCMAWindow::cell_data_license(Gtk::CellRenderer *renderer, const Gtk::TreeI
     cell->property_text() = cell->property_text() + " " + *i;
 
   cell->property_text() = cell->property_text() + " " + a[1];
+  */
 }
 
+void VCMAWindow::cell_data_song_and_artist(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i)
+{
+  Gtk::CellRendererText*cell = dynamic_cast<Gtk::CellRendererText*>(renderer);
+  cell->property_markup() = "<b>" + (*i)[songs_columns.song_title] + 
+    "</b>\nby: <u>" + (*i)[songs_columns.artist_name] +"</u>";
+}
+
+void VCMAWindow::cell_data_rating(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i)
+{
+  Gtk::CellRendererPixbuf *cell = 
+    dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);
+
+  double rating = (*i)[songs_columns.album_rating];
+  if (rating > 9.5)
+    cell->property_pixbuf() = Gdk::Pixbuf::create_from_file
+      (Main::get_data_path() + "/5of5.svg", 67, 13);
+  else if (rating > 8.5)
+    cell->property_pixbuf() = Gdk::Pixbuf::create_from_file
+      (Main::get_data_path() + "/4hvof5.svg", 67, 13);
+  else if (rating > 7.5)
+    cell->property_pixbuf() = Gdk::Pixbuf::create_from_file
+      (Main::get_data_path() + "/4of5.svg", 67, 13);
+  else if (rating > 6.5)
+    cell->property_pixbuf() = Gdk::Pixbuf::create_from_file
+      (Main::get_data_path() + "/3hvof5.svg", 67, 13);
+  else if (rating > 5.5)
+    cell->property_pixbuf() = Gdk::Pixbuf::create_from_file
+      (Main::get_data_path() + "/3of5.svg", 67, 13);
+  else if (rating > 4.5)
+    cell->property_pixbuf() = Gdk::Pixbuf::create_from_file
+      (Main::get_data_path() + "/2hvof5.svg", 67, 13);
+  else if (rating > 3.5)
+    cell->property_pixbuf() = Gdk::Pixbuf::create_from_file
+      (Main::get_data_path() + "/2of5.svg", 67, 13);
+  else if (rating > 2.5)
+    cell->property_pixbuf() = Gdk::Pixbuf::create_from_file
+      (Main::get_data_path() + "/1hvof5.svg", 67, 13);
+  else if (rating > 1.5)
+    cell->property_pixbuf() = Gdk::Pixbuf::create_from_file
+      (Main::get_data_path() + "/1of5.svg", 67, 13);
+  else if (rating > 0.5)
+    cell->property_pixbuf() = Gdk::Pixbuf::create_from_file
+      (Main::get_data_path() + "/0hvof5.svg", 67, 13);
+    //cell->property_text() = Glib::ustring::format(std::fixed, std::setprecision(1), (*i)[songs_columns.album_rating]);
+}
+
+
 void VCMAWindow::cell_data_duration(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i)
 {
   Gtk::CellRendererText*cell = dynamic_cast<Gtk::CellRendererText*>(renderer);
