@@ -42,7 +42,8 @@ class VCMAWindow: public Gtk::Window
   public:
       SongsColumns()
 	{add(duration); add(genre); add(song_title); add(artist_name); 
-          add(album_id); add(track_id); add(license);}
+          add(album_id); add(track_id); add(license); add(license_image), 
+            add(album_rating);}
       Gtk::TreeModelColumn<guint32> duration;
       Gtk::TreeModelColumn<Glib::ustring> genre;
       Gtk::TreeModelColumn<Glib::ustring> song_title;
@@ -50,6 +51,8 @@ class VCMAWindow: public Gtk::Window
       Gtk::TreeModelColumn<guint32> album_id;
       Gtk::TreeModelColumn<guint32> track_id;
       Gtk::TreeModelColumn<Glib::ustring> license;
+      Gtk::TreeModelColumn<Glib::RefPtr<Gdk::Pixbuf> > license_image;
+      Gtk::TreeModelColumn<double> album_rating;
     };
     const SongsColumns songs_columns;
     Glib::RefPtr<Gtk::ListStore> songs_list;
@@ -57,9 +60,17 @@ class VCMAWindow: public Gtk::Window
     Gtk::CellRendererText duration_renderer;
     Gtk::TreeViewColumn duration_column;
     void cell_data_duration(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i);
-    Gtk::CellRendererText license_renderer;
+    Gtk::CellRendererPixbuf license_renderer;
     Gtk::TreeViewColumn license_column;
     void cell_data_license(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i);
+
+    Gtk::CellRendererText song_and_artist_renderer;
+    Gtk::TreeViewColumn song_and_artist_column;
+    void cell_data_song_and_artist(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i);
+
+    Gtk::CellRendererPixbuf rating_renderer;
+    Gtk::TreeViewColumn rating_column;
+    void cell_data_rating(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i);
     
     //widgets
     Gtk::Box *contents;
@@ -75,6 +86,7 @@ class VCMAWindow: public Gtk::Window
     Gtk::Button *about_button;
     Gtk::Button *video_filechooser_button;
     Gtk::Box *video_file_box;
+    Gtk::Statusbar *statusbar;
 
     Gtk::Menu treeview_context_menu;
 
@@ -97,7 +109,7 @@ class VCMAWindow: public Gtk::Window
     void on_about_clicked();
 
     void on_album_license_not_loaded(guint32 album_id, TrackList *songs);
-    void on_album_license_loaded(guint32 album_id, Glib::ustring license, TrackList *songs);
+    void on_album_license_loaded(guint32 album_id, Glib::ustring license, Glib::RefPtr<Gdk::Pixbuf> license_image, double rating, TrackList *songs);
     void on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context,
                                int, int, 
                                const Gtk::SelectionData& selection_data,
@@ -106,7 +118,7 @@ class VCMAWindow: public Gtk::Window
 
     //helpers
     bool quit();
-    void add_song_row(const Track &track);
+    void add_song_row(const Track &track, Glib::RefPtr<Gdk::Pixbuf> license_image);
     void search_tracks_in_the_background(TrackList *track_list, guint32 duration);
     void load_catalogue_in_the_background(TrackList *track_list, guint32 duration);
     void show_spinner();
